#!/usr/bin/env python3
# -*- coding: utf-8 -*-



# recursive print function
def rec_print_list(lst):
    for i in lst:
        if(isinstance(i, list)):
            rec_print_list(i)
        else:
            print(i)





#!/usr/bin/env python3
# -*- coding: utf-8 -* 


from distutils.core import setup
#from setuptools import setup

setup(name = "printListModule_jk", version="1.0.0", description="an API to print \
      a list recursively", author="jkmenon", author_email="jk.menon@ignitarium.com", \
          py_modules=["printListModule_jk"])
